package edu.lawrence.mazedrawing;

import java.io.File;
import java.io.PrintWriter;
import java.util.ArrayList;
import javafx.scene.input.MouseEvent;
import javafx.scene.layout.Pane;
import javafx.scene.paint.Color;
import javafx.scene.shape.Circle;

public class MazePane extends Pane {

    private ArrayList<Wall> walls;
    private Wall dragging;

    public MazePane() {
        walls = new ArrayList<Wall>();
        for (int row = 0; row <= 11; row++) {
            for (int col = 0; col <= 16; col++) {
                Circle circle = new Circle();
                circle.setCenterX(col * 40);
                circle.setCenterY(row * 40);
                circle.setFill(Color.RED);
                circle.setRadius(2);
                this.getChildren().add(circle);
            }
        }
        this.setOnMousePressed(e -> startDrag(e));
        this.setOnMouseDragged(e -> dragSegment(e));
        this.setOnMouseReleased(e -> endDrag(e));
    }

    public void startDrag(MouseEvent e) {
        dragging = new Wall(e.getX(), e.getY());
        walls.add(dragging);
        this.getChildren().add(dragging.getShape());
    }

    public void dragSegment(MouseEvent e) {
        dragging.setEnd(e.getX(), e.getY());
    }

    public void endDrag(MouseEvent e) {
        dragging.snapToGrid(e.getX(), e.getY());
        dragging = null;
    }

    public void save() {
        try {
            PrintWriter out = new PrintWriter(new File("maze.txt"));
            out.println(walls.size());
            for (Wall w : walls) {
                w.write(out);
            }
            out.close();
        } catch (Exception ex) {
            ex.printStackTrace();
        }
    }
}
